@@ -1,7 +1,7 @@
 #ifndef PARSER_H_62B23520_7C8E_11DE_8A39_0800200C9A66
 #define PARSER_H_62B23520_7C8E_11DE_8A39_0800200C9A66
 
-#if !defined(__GNUC__) || (__GNUC__ == 3 && __GNUC_MINOR__ >= 4) || (__GNUC__ >= 4) // GCC supports "pragma once" correctly since 3.4
+#if defined(_MSC_VER) || (defined(__GNUC__) && (__GNUC__ == 3 && __GNUC_MINOR__ >= 4) || (__GNUC__ >= 4)) // GCC supports "pragma once" correctly since 3.4
 #pragma once
 #endif
 
@@ -32,7 +32,8 @@ namespace YAML
 		void Load(std::istream& in);
 		bool HandleNextDocument(EventHandler& eventHandler);
 		
-		bool GetNextDocument(Node& document);
+		bool GetNextDocument(Node& document); // old API only
+		
 		void PrintTokens(std::ostream& out);
 
 	private:
